@@ -264,6 +264,10 @@ weston_desktop_xdg_surface_committed(struct weston_desktop_surface *dsurface,
 		weston_desktop_surface_get_surface(surface->surface);
 	bool reconfigure = false;
 
+	/* TODO: use the window geometry and not the surface size here
+	 * We need to check the next geometry if there is one, but not accept it
+	 * until we checked it, maybe.
+	 */
 	if (surface->next.state.maximized || surface->next.state.fullscreen)
 		reconfigure = surface->next.size.width != wsurface->width ||
 			      surface->next.size.height != wsurface->height;
@@ -477,8 +481,10 @@ weston_desktop_xdg_surface_protocol_ack_configure(struct wl_client *wl_client,
 		} else if (configure->serial == serial) {
 			wl_list_remove(&configure->link);
 			found = true;
+			break;
+		} else {
+			break;
 		}
-		break;
 	}
 	if (!found) {
 		struct weston_desktop_client *client =
